@@ -386,7 +386,7 @@ class Locale(object):
         ('fi_FI', {
             'name': 'Suomi (Suomi)',
             'locale': 'fi_FI.utf8',
-            'keymap': 'fi-latin1',
+            'keymap': 'fi',
             'timezone': 'Europe/Helsinki',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
